.. # README file for Pypi

Pywbem is a WBEM client, written in pure Python. It supports Python 2 and
Python 3. Pywbem also contains a WBEM indication listener.

A WBEM client allows issuing operations to a WBEM server, using the
`CIM/WBEM standards`_ defined by the DMTF, for the purpose of performing
systems management tasks. A WBEM indication listener is used to wait for
and process notifications emitted by a WBEM server, also for the purpose
of systems management.

CIM/WBEM infrastructure is used for a wide variety of systems management
tasks in the industry.

For more information on pywbem, see the `pywbem readme`_, and the
`pywbem documentation`_.

.. _pywbem readme: https://github.com/pywbem/pywbem/blob/stable_0.14/README.rst
.. _pywbem documentation: https://pywbem.readthedocs.io/en/stable_0.14/
.. _CIM/WBEM standards: https://www.dmtf.org/standards/wbem/
